@@ -119,7 +119,7 @@ class App:
         if context is None:
             context = {}
 
-        return Environment(loader=FileSystemLoader(os.path.abspath(templates_path))).get_template(template_name).render(**context).encode()
+        return Environment(loader=FileSystemLoader(templates_path)).get_template(template_name).render(**context).encode()
 
     def add_middleware(self, middleware_cls):
         self.middleware.add(middleware_cls)
