@@ -19,5 +19,5 @@ class DefaultExceptionHandler:
     def handle_error(self, request, response, error):
         response.status_code = 500
         response.body = self.app.custom_template(pathlib.Path("selfpages").absolute(),
-                                                 "index.html", context={"error": str(error)})
+                                                 "error-500.html", context={"error": str(error)})
 
